Running
=======

Once the service library has been installed and the configuration files are populated it can be started by
executing the following command line:

    .. parsed-literal::

        python -m dxlmaxmindservice <configuration-directory>

    The ``<configuration-directory>`` argument must point to a directory containing the configuration files
    required for the service (see :doc:`configuration`).

For example:

    .. parsed-literal::

        python -m dxlmaxmindservice config
